@@ -26,7 +26,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.7.04"
+version = "0.7.10"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -153,8 +153,8 @@ encryption = True
 # If set to false, then do not compress files on remote system
 compression = True
 
-# volume size. default 25M
-volsize = 25 * 1024 * 1024
+# volume size. default 200M
+volsize = 200 * 1024 * 1024
 
 # Working directory for the tempfile module. Defaults to /tmp on most systems.
 temproot = None
@@ -191,6 +191,9 @@ s3_unencrypted_connection = False
 # Whether to use S3 Reduced Redudancy Storage
 s3_use_rrs = False
 
+# Whether to use S3 Infrequent Access Storage
+s3_use_ia = False
+
 # True if we should use boto multiprocessing version
 s3_use_multiprocessing = False
 
@@ -239,8 +242,9 @@ ssh_options = ""
 # default cf backend is pyrax
 cf_backend = "pyrax"
 
-# HTTPS ssl optons (currently only webdav)
+# HTTPS ssl options (currently only webdav, lftp)
 ssl_cacert_file = None
+ssl_cacert_path = None
 ssl_no_check_certificate = False
 
 # user added rsync options
